@@ -31,7 +31,8 @@ Finance::QuoteDB - User database tools based on Finance::Quote
 @EXPORT = ();
 @EXPORT_OK = qw /createdb updatedb addstock/ ;
 @EXPORT_TAGS = ( all => [@EXPORT_OK] );
-$VERSION = '0.15';
+
+our $VERSION = '0.16'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -389,7 +390,7 @@ sub add_yahoo_stocks {
     }  ;
 
     no strict 'subs' ;
-    if (!defined(@$refsearchlist)) {
+    if (!@$refsearchlist) {
       $refsearchlist = [AA .. ZZ] ;
       $$refsearchlist[$_] = "**".$$refsearchlist[$_] foreach (0 .. $#{@$refsearchlist}) ; # add ** in front of each list item
     }
